==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarContListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$ToolBarContListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1bdd7f34f44f06b4 javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *);
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarContListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$ToolBarContListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b1f365fb97845bb2 javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarContListener_H_ */
